﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data.Entity;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ZachPreparing
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ObservableCollection<Service> ShowingServices { get; set; } = new ObservableCollection<Service>();


        public MainWindow()
        {
            InitializeComponent();
            ListViewMain.ItemsSource = ShowingServices;
            GetAllServicesFromDB();
            foreach(var i in _services) ShowingServices.Add(i);
            SortingComboBox.SelectedIndex = 0;
            FiltredComboBox.SelectedIndex = 0;
            SearchField.Text = "";
        }


        /// <summary>
        /// Получение списка сервисов из БД
        /// </summary>
        private void GetAllServicesFromDB()
        {
            using(DBConnectionString DB = new DBConnectionString())
            {
                _services = DB.Service.ToList<Service>();
            }
        }
        /// <summary>
        /// Обновление списка отображаемых сервисов
        /// </summary>
        public void UpdateShowingServices()
        {
            ShowingServices.Clear();
            Sorting(Searching(Filtring()));
        }
        /// <summary>
        /// Фильтрация
        /// </summary>
        /// <returns>Отфильтрованная коллекция</returns>
        private List<Service> Filtring()
        {
            List<Service> TempList = new List<Service>();
            switch(FiltredComboBox.SelectedIndex)
            {
                case 0:
                    foreach(var i in _services)
                    {
                        TempList.Add(i);
                    }
                    break;
                case 1:
                    foreach (var i in _services)
                    {
                        if(i.Discount >= 0 && i.Discount < 0.05) TempList.Add(i);
                    }
                    break;
                case 2:
                    foreach (var i in _services)
                    {
                        if (i.Discount >= 0.05 && i.Discount < 0.15) TempList.Add(i);
                    }
                    break;
                case 3:
                    foreach (var i in _services)
                    {
                        if (i.Discount >= 0.15 && i.Discount < 0.30) TempList.Add(i);
                    }
                    break;
                case 4:
                    foreach (var i in _services)
                    {
                        if (i.Discount >= 0.30 && i.Discount < 0.70) TempList.Add(i);
                    }
                    break;
                case 5:
                    foreach (var i in _services)
                    {
                        if (i.Discount >= 0.70 && i.Discount < 1.00) TempList.Add(i);
                    }
                    break;
            }
            return TempList;
        }
        /// <summary>
        /// Поиск
        /// </summary>
        /// <param name="services">Коллекция сервисов</param>
        /// <returns>Сервисы подходящие под поиск</returns>
        private List<Service> Searching(List<Service> services)
        {
            List<Service> TempList = new List<Service>();
            foreach (var service in services) 
            {
                if(Regex.IsMatch(service.Title, SearchField.Text))
                {
                    TempList.Add(service);
                }
            }
            return TempList;
        }
        /// <summary>
        /// Сортировка сервисов
        /// </summary>
        /// <param name="services">Коллекция сервисов</param>
        private void Sorting(List<Service> services)
        {
            switch(SortingComboBox.SelectedIndex)
            {
                case 0:
                    foreach (var service in services) ShowingServices.Add(service);
                    return;
                case 1:
                    ShowingServices = new ObservableCollection<Service>(services.OrderBy(a => a.Cost));
                    ListViewMain.ItemsSource = ShowingServices;
                    return;
                case 2:
                    ShowingServices = new ObservableCollection<Service>(services.OrderByDescending(a => a.Cost));
                    ListViewMain.ItemsSource = ShowingServices;
                    return;
            }
        }

        private void FiltredComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e) => UpdateShowingServices();

        private void SortingComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e) => UpdateShowingServices();

        private void SearchField_TextChanged(object sender, TextChangedEventArgs e) => UpdateShowingServices();

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Window wn = new AddNewServiceWindow();
            wn.ShowDialog();
        }

        private void Button_Red(object sender, RoutedEventArgs e)
        {
            Window wn = new AddNewServiceWindow(Convert.ToInt32(((Button)sender).Uid));
            wn.ShowDialog();
        }

        private void Button_Del(object sender, RoutedEventArgs e)
        {

        }


        private List<Service> _services = new List<Service>();
    }
}
